@@ -1,11 +1,11 @@
-static void Slirp_usage_err(int i, int last)
+static void Slirp_usage(int i, int last, int vectorized) /* {{{ */
 {
    char *indent;
    int npop = SLstack_depth();
    if (npop > SLang_Num_Function_Args) npop = SLang_Num_Function_Args;
    SLdo_pop_n(npop);
    if (last == i)
-	indent = (char*)"Usage: ";
+	indent = (char*)"Usage:  ";
    else {
 	indent = (char*)"\t";
 	SLang_verror(SLEU, (char*)"Usage: one of");
@@ -13,4 +13,6 @@ static void Slirp_usage_err(int i, int last)
    do
 	SLang_verror(SLEU, (char*)"%s%s", indent, usage_strings[i++]);
    while (i < last);
-}
+   if (vectorized)
+	SLang_verror(SLEU, (char*)"\tThis function has been vectorized.");
+} /* }}} */
